@@ -275,11 +275,12 @@ def serialize_object(cls, inst, include_fields=None, extend_fields=None):
     if not isinstance(inst, cls):
         return inst
     logger.debug('serialize_object> extend_fields: %s', extend_fields)
-    include_fields = list(set(include_fields or cls.__table__.c.keys()) | set(cls.__table__.primary_key.columns.keys()))
-    if not set(include_fields) <= set(cls.__table__.c.keys()):
-        raise BadRequest(message='Column(s) "%s" does not exists!' % ','.join(list(
-            set(include_fields) - set(cls.__table__.c.keys())
-        )))
+    include_fields = include_fields or cls.__table__.c.keys()
+    include_fields = list(set(include_fields) | set(cls.__table__.primary_key.columns.keys()))
+    #if not set(include_fields) <= set(cls.__mapper__.c.keys()):
+    #    raise BadRequest(message='Column(s) "%s" does not exists!' % ','.join(list(
+    #        set(include_fields) - set(cls.__mapper__.c.keys())
+    #    )))
     result = dict((k, getattr(inst, k)) for k in include_fields)
     if extend_fields:
         logger.debug('serialize_object: extend_fields=%s', extend_fields)
@@ -287,8 +288,8 @@ def serialize_object(cls, inst, include_fields=None, extend_fields=None):
             rinst = cls.__mapper__.relationships[relkey]
             logger.debug('====> %s: %s', relkey, relext)
             #if rinst.direction.name in ('MANYTOONE', 'ONETOONE'):
-            incs = filter(lambda x: x.find('.') < 0 and x in rinst.mapper.class_.__table__.c.keys(), relext)
-            #[relext] if (relext and relext.find('.') < 0 and relext in rinst.mapper.class_.__table__.c.keys()) else None
+            incs = filter(lambda x: x.find('.') < 0 and x in rinst.mapper.class_.__mapper__.c.keys(), relext)
+            #[relext] if (relext and relext.find('.') < 0 and relext in rinst.mapper.class_.__mapper__.c.keys()) else None
             exts = filter(lambda x: x.find('.') > 0 or x in rinst.mapper.class_.__mapper__.relationships.keys(), relext)
             #[relext] if relext and incs is None else None
             logger.debug('inc=%s, ext=%s', incs, exts)
@@ -357,12 +358,17 @@ class ExpressController(RestController):
                  permissions=None,
                  readonly=None,
                  subcontrollers=None,
+                 extra_attrs=None,
                  **kwargs):
         if model is not None:
             self._model_ = model
         self._dbsession_ = dbsession
         if self._model_ is None:
             raise Exception('"_model_" can not be None, must be a valid model class of sqlalchemy!')
+        self._columns_ = self._model_.__table__.c.keys()
+        if extra_attrs is not None:
+            extra_attrs = extra_attrs if isinstance(extra_attrs, (list, tuple)) else extra_attrs.split(',')
+            self._columns_.extend(extra_attrs)
         if self._dbsession_ is None:
             raise Exception("A valid db session is required!")
         if allow_only is not None:
@@ -533,7 +539,8 @@ class ExpressController(RestController):
 
         #if meta.invisible:
         #    exclude_fields = exclude_fields.extend(meta.invisible) if exclude_fields else meta.invisible
-        include_fields = list((set(include_fields or self._model_.__table__.columns.keys()) - set(exclude_fields or []))
+        include_fields = list((set(include_fields or self._columns_)
+                               - set(exclude_fields or []))
                               | set(self._model_.__table__.primary_key.columns.keys()))
         if extend_fields:
             logger.debug('extend_fields: %s', extend_fields)
